Learn R Programming

vegan (version 2.7-6)

mso: Functions for performing and displaying a spatial partitioning of cca or rda results

Description

The function mso adds an attribute vario to an object of class "cca" that describes the spatial partitioning of the cca object and performs an optional permutation test for the spatial independence of residuals. The function plot.mso creates a diagnostic plot of the spatial partitioning of the "cca" object.

Usage

mso(object.cca, object.xy, grain = 1, round.up = FALSE, permutations = 0)
msoplot(x, alpha = 0.05, explained = FALSE, ylim = NULL, legend = "topleft", ...)

Arguments

Value

The function mso returns an amended cca or rda

object with the additional attributes grain, H,

H.test and vario.

grain

The grain attribute defines the interval size of the distance classes .

H

H is an object of class 'dist' and contains the geographic distances between observations.

H.test

H.test contains a set of dummy variables that describe which pairs of observations (rows = elements of object$H) fall in which distance class (columns).

vario

The vario attribute is a data frame that contains some or all of the following components for the rda case (cca case in brackets):

H

Distance class as multiples of grain.

Dist

Average distance of pairs of observations in distance class H.

n

Number of unique pairs of observations in distance class H.

All

Empirical (chi-square) variogram of total variance (inertia).

Sum

Sum of empirical (chi-square) variograms of explained and residual variance (inertia).

CA

Empirical (chi-square) variogram of residual variance (inertia).

CCA

Empirical (chi-square) variogram of explained variance (inertia).

pCCA

Empirical (chi-square) variogram of conditioned variance (inertia).

se

Standard error of the empirical (chi-square) variogram of total variance (inertia).

CA.signif

P-value of permutation test for spatial independence of residual variance (inertia).

Details

The Mantel test is an adaptation of the function mantel to the parallel testing of several distance classes and similar to multivariate mantel.correlog. It compares the mean inertia in each distance class to the pooled mean inertia of all other distance classes.

If there are explanatory variables (RDA, CCA, pRDA, pCCA) and a significance test for residual autocorrelation was performed when running the function mso, the function plot.mso will print an estimate of how much the autocorrelation (based on significant distance classes) causes the global error variance of the regression analysis to be underestimated

References

Wagner, H.H. 2004. Direct multi-scale ordination with canonical correspondence analysis. Ecology 85: 342--351.

See Also

mantel.correlog.

Examples

Run this code
## Reconstruct worked example of Wagner (submitted):
X <- matrix(c(1, 2, 3, 2, 1, 0), 3, 2)
Y <- c(3, -1, -2)
tmat <- c(1:3)
## Canonical correspondence analysis (cca):
Example.cca <- cca(X, Y)
Example.cca <- mso(Example.cca, tmat)
msoplot(Example.cca)
Example.cca$vario

## Correspondence analysis (ca):
Example.ca <- mso(cca(X), tmat)
msoplot(Example.ca)

## Unconstrained ordination with test for autocorrelation
## using oribatid mite data set as in Wagner (2004)
data(mite)
data(mite.env)
data(mite.xy)

mite.cca <- cca(log(mite + 1))
mite.cca <- mso(mite.cca, mite.xy, grain =  1, permutations = 99)
msoplot(mite.cca)
mite.cca

## Constrained ordination with test for residual autocorrelation
## and scale-invariance of species-environment relationships
mite.cca <- cca(log(mite + 1) ~ SubsDens + WatrCont + Substrate + Shrub + Topo, mite.env)
mite.cca <- mso(mite.cca, mite.xy, permutations = 99)
msoplot(mite.cca)
mite.cca

Run the code above in your browser using DataLab