## S3 method for class 'cca':
add1(object, scope, test = c("none", "permutation"),
pstep = 100, perm.max = 200, ...)
## S3 method for class 'cca':
drop1(object, scope, test = c("none", "permutation"),
pstep = 100, perm.max = 200, ...)add1 for details.anova.cca.step to anova.cca.anova.cca.add1.default,
drop1.default, and anova.cca.test = "none" the functions will only call
add1.default or drop1.default. With
argument test = "permutation" the functions will add test
results from anova.cca. Function drop1.cca will
call anova.cca with argument by = "margin".
Function add1.cca will implement a test for single term
additions that is not directly available in anova.cca. Functions are used implicity in step. The
deviance.cca and deviance.rda used in
step have no firm basis, and setting argument
test = "permutation" may help in getting useful insight into
validity of model building. Meticulous use of add1.cca and
drop1.cca will allow more judicious model building.
The default perm.max is set to a low value, because
permutation tests can take a long time. It should be sufficient to
give a impression on the significances of the terms, but higher
values of perm.max should be used if $P$ values really
are important.
add1, drop1 and
anova.cca for basic methods. You probably need these
functions with step. Functions
deviance.cca and extractAIC.cca are used
to produce the other arguments than test results in the
output. Functions cca, rda and
capscale produce result objects for these functions.data(varespec)
data(varechem)
step(rda(varespec ~ 1, varechem), reformulate(names(varechem)), test="perm")Run the code above in your browser using DataLab