| biplot.rda | R Documentation |
Draws a PCA biplot with species scores indicated by biplot arrows
## S3 method for class 'rda'
biplot(x, choices = c(1, 2), scaling = "species",
display = c("sites", "species"), type, xlim, ylim, col = c(1,2),
const, correlation = FALSE, ...)
x |
A |
choices |
Axes to show. |
scaling |
Scaling for species and site scores. Either species
( The type of scores can also be specified as one of |
correlation |
logical; if |
display |
Scores shown. These must some of the alternatives
|
type |
Type of plot: partial match to |
xlim, ylim |
the x and y limits (min, max) of the plot. |
col |
Colours used for sites and species (in this order). If only one colour is given, it is used for both. |
const |
General scaling constant for |
... |
Other parameters for plotting functions. |
Produces a plot or biplot of the results of a call to
rda. It is common for the "species" scores in a PCA to
be drawn as biplot arrows that point in the direction of increasing
values for that variable. The biplot.rda function provides a
wrapper to plot.cca to allow the easy production of such a
plot.
biplot.rda is only suitable for unconstrained models. If
used on an ordination object with constraints, an error is issued.
Arrow heads are at the actual species scores, and the possible text is projected to direction of the arrow.
The plot function returns invisibly a plotting structure which
can be used by identify.ordiplot to identify
the points or other functions in the ordiplot family.
Prior to vegan 2.7-2 the species text was at the
actual location and arrows were shorter than with points.
Gavin Simpson and Jari Oksanen.
plot.cca can also draw biplot arrows since
vegan 2.7-0.
data(dune)
mod <- rda(dune, scale = TRUE)
biplot(mod, scaling = "symmetric")
## plot.cca can do the same
plot(mod, scaling = "symmetric", spe.par = list(arrows=TRUE))
## different type for species and site scores
biplot(mod, scaling = "symmetric", type = c("text", "points"))
## We can use ordiplot pipes to build similar plots with flexible
## control
plot(mod, scaling = "symmetric", type="n") |>
points("sites", cex=0.7) |>
text("species", arrows=TRUE, length=0.05, col=2, cex=0.7, font=3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.