dune data
set.data(dune.taxon)
data(dune.phylodis)dune.taxon is data frame with 30 species (rows) classified
into five taxonomic levels (columns). dune.phylodis is a
dist object of estimated coalescence ages extracted
from Hill, M.O et al. (2006) An annotated checklist of the mosses of Europe and Macaronesia. J. Bryology 28: 198--267.
Zanne A.E., Tank D.C., Cornwell, W.K., Eastman J.M., Smith, S.A., FitzJohn, R.G., McGlinn, D.J., O’Meara, B.C., Moles, A.T., Reich, P.B., Royer, D.L., Soltis, D.E., Stevens, P.F., Westoby, M., Wright, I.J., Aarssen, L., Bertin, R.I., Calaminus, A., Govaerts, R., Hemmings, F., Leishman, M.R., Oleksyn, J., Soltis, P.S., Swenson, N.G., Warman, L. & Beaulieu, J.M. (2014) Three keys to the radiation of angiosperms into freezing environments. Nature 506, 89--92.
taxondive, treedive,
and treedist use these data sets.data(dune.taxon)
data(dune.phylodis)Run the code above in your browser using DataLab