ordiplot always plots only unlabelled points, but
identify.ordiplot can be used to add labels to selected site,
species or constraint points. Function identify.ordiplot can
be used to identify points from plot.cca,
plot.decorana or plot.procrustes as well.ordiplot(ord, choices = c(1, 2), type="points", ...)
## S3 method for class 'ordiplot':
identify(x, what, ...)ordiplot.ordiplot returns invisibly an object of class
"ordiplot" with items sites, species and
constraints (if these are available in the ordination
object). Function identify.ordiplot uses this object to label
the point.ordiplot draws an ordination diagram using black circles for
sites and red crosses for species. It returns invisibly an object of
class "ordiplot" which can be used by identify.ordiplot
to label selected sites or species, or constraints in
cca and rda. The function can handle output from several alternative ordination
methods. For cca, rda and
decorana it uses their plot method with option
type = "points". In addition, the plot functions of
these methods return invisibly an "ordiplot" object which can
be used by identify.ordiplot to label points. For other
ordinations it relies on scores to extract the scores.
identify for basic operations, plot.cca,
plot.decorana, plot.procrustes which also
produce objects for
identify.ordiplot and scores for extracting
scores from non-vegan ordinations.data(dune)
ordina <- cca(dune)
tmp <- ordiplot(ordina)
# identify needs user interaction
identify(tmp, "spec")Run the code above in your browser using DataLab