Skip to contents

Function specaccum finds species accumulation curves or the number of species for a certain number of sampled sites or individuals.

Usage

specaccum(comm, method = "exact", permutations = 100,
          conditioned =TRUE, gamma = "jack1",  w = NULL, subset, ...)
# S3 method for class 'specaccum'
plot(x, add = FALSE, random = FALSE, ci = 2, 
    ci.type = c("bar", "line", "polygon"), col = par("fg"), lty = 1,
    ci.col = col, ci.lty = 1, ci.length = 0, xlab, ylab = x$method, ylim,
    xvar = c("sites", "individuals", "effort"), ...)
# S3 method for class 'specaccum'
boxplot(x, add = FALSE, ...)
fitspecaccum(object, model, method = "random", ...)
# S3 method for class 'fitspecaccum'
plot(x, col = par("fg"), lty = 1, xlab = "Sites", 
    ylab = x$method, ...) 
# S3 method for class 'specaccum'
predict(object, newdata, interpolation = c("linear", "spline"), ...)
# S3 method for class 'fitspecaccum'
predict(object, newdata, ...)
specslope(object, at)

Arguments

comm

Community data set.

method

Species accumulation method (partial match). Method "collector" adds sites in the order they happen to be in the data, "random" adds sites in random order, "exact" finds the expected (mean) species richness, "coleman" finds the expected richness following Coleman et al. 1982, and "rarefaction" finds the mean when accumulating individuals instead of sites.

permutations

Number of permutations with method = "random". Usually an integer giving the number permutations, but can also be a list of control values for the permutations as returned by the function how, or a permutation matrix where each row gives the permuted indices.

conditioned

Estimation of standard deviation is conditional on the empirical dataset for the exact SAC

gamma

Method for estimating the total extrapolated number of species in the survey area by function specpool

w

Weights giving the sampling effort.

subset

logical expression indicating sites (rows) to keep: missing values are taken as FALSE.

x

A specaccum result object

add

Add to an existing graph.

random

Draw each random simulation separately instead of drawing their average and confidence intervals.

ci

Multiplier used to get confidence intervals from standard deviation (standard error of the estimate). Value ci = 0 suppresses drawing confidence intervals.

ci.type

Type of confidence intervals in the graph: "bar" draws vertical bars, "line" draws lines, and "polygon" draws a shaded area.

col

Colour for drawing lines.

lty

line type (see par).

ci.col

Colour for drawing lines or filling the "polygon".

ci.lty

Line type for confidence intervals or border of the "polygon".

ci.length

Length of horizontal bars (in inches) at the end of vertical bars with ci.type = "bar".

xlab,ylab

Labels for x (defaults xvar) and y axis.

ylim

the y limits of the plot.

xvar

Variable used for the horizontal axis: "individuals" can be used only with method = "rarefaction".

object

Either a community data set or fitted specaccum model.

model

Nonlinear regression model (nls). See Details.

newdata

Optional data used in prediction interpreted as number of sampling units (sites). If missing, fitted values are returned.

interpolation

Interpolation method used with newdata.

at

Number of plots where the slope is evaluated. Can be a real number.

...

Other parameters to functions.

Details

Species accumulation curves (SAC) are used to compare diversity properties of community data sets using different accumulator functions. The classic method is "random" which finds the mean SAC and its standard deviation from random permutations of the data, or subsampling without replacement (Gotelli & Colwell 2001). The "exact" method finds the expected SAC using sample-based rarefaction method that has been independently developed numerous times (Chiarucci et al. 2008) and it is often known as Mao Tau estimate (Colwell et al. 2012). The unconditional standard deviation for the exact SAC represents a moment-based estimation that is not conditioned on the empirical data set (sd for all samples > 0). The unconditional standard deviation is based on an estimation of the extrapolated number of species in the survey area (a.k.a. gamma diversity), as estimated by function specpool. The conditional standard deviation that was developed by Jari Oksanen (not published, sd=0 for all samples). Method "coleman" finds the expected SAC and its standard deviation following Coleman et al. (1982). All these methods are based on sampling sites without replacement. In contrast, the method = "rarefaction" finds the expected species richness and its standard deviation by sampling individuals instead of sites. It achieves this by applying function rarefy with number of individuals corresponding to average number of individuals per site.

Methods "random" and "collector" can take weights (w) that give the sampling effort for each site. The weights w do not influence the order the sites are accumulated, but only the value of the sampling effort so that not all sites are equal. The summary results are expressed against sites even when the accumulation uses weights (methods "random", "collector"), or is based on individuals ("rarefaction"). The actual sampling effort is given as item Effort or Individuals in the printed result. For weighted "random" method the effort refers to the average effort per site, or sum of weights per number of sites. With weighted method = "random", the averaged species richness is found from linear interpolation of single random permutations. Therefore at least the first value (and often several first) have NA richness, because these values cannot be interpolated in all cases but should be extrapolated. The plot function defaults to display the results as scaled to sites, but this can be changed selecting xvar = "effort" (weighted methods) or xvar = "individuals" (with method = "rarefaction").

The summary and boxplot methods are available for method = "random".

Function predict for specaccum can return the values corresponding to newdata. With method "exact", "rarefaction" and "coleman" the function uses analytic equations for interpolated non-integer values, and for other methods linear (approx) or spline (spline) interpolation. If newdata is not given, the function returns the values corresponding to the data. NB., the fitted values with method="rarefaction" are based on rounded integer counts, but predict can use fractional non-integer counts with newdata and give slightly different results.

Function fitspecaccum fits a nonlinear (nls) self-starting species accumulation model. The input object can be a result of specaccum or a community in data frame. In the latter case the function first fits a specaccum model and then proceeds with fitting the nonlinear model. The function can apply a limited set of nonlinear regression models suggested for species-area relationship (Dengler 2009). All these are selfStart models. The permissible alternatives are "arrhenius" (SSarrhenius), "gleason" (SSgleason), "gitay" (SSgitay), "lomolino" (SSlomolino) of vegan package. In addition the following standard R models are available: "asymp" (SSasymp), "gompertz" (SSgompertz), "michaelis-menten" (SSmicmen), "logis" (SSlogis), "weibull" (SSweibull). See these functions for model specification and details.

When weights w were used the fit is based on accumulated effort and in model = "rarefaction" on accumulated number of individuals. The plot is still based on sites, unless other alternative is selected with xvar.

Function predict for fitspecaccum uses predict.nls, and you can pass all arguments to that function. In addition, fitted, residuals, nobs, coef, AIC, logLik and deviance work on the result object.

Function specslope evaluates the derivative of the species accumulation curve at given number of sample plots, and gives the rate of increase in the number of species. The function works with specaccum result object when this is based on analytic models "exact", "rarefaction" or "coleman", and with non-linear regression results of fitspecaccum.

Nonlinear regression may fail for any reason, and some of the fitspecaccum models are fragile and may not succeed.

Value

Function specaccum returns an object of class "specaccum", and fitspecaccum a model of class "fitspecaccum" that adds a few items to the "specaccum" (see the end of the list below):

call

Function call.

method

Accumulator method.

sites

Number of sites. For method = "rarefaction" this is the number of sites corresponding to a certain number of individuals and generally not an integer, and the average number of individuals is also returned in item individuals.

effort

Average sum of weights corresponding to the number of sites when model was fitted with argument w

richness

The number of species corresponding to number of sites. With method = "collector" this is the observed richness, for other methods the average or expected richness.

sd

The standard deviation of SAC (or its standard error). This is NULL in method = "collector", and it is estimated from permutations in method = "random", and from analytic equations in other methods.

perm

Permutation results with method = "random" and NULL in other cases. Each column in perm holds one permutation.

weights

Matrix of accumulated weights corresponding to the columns of the perm matrix when model was fitted with argument w.

fitted, residuals, coefficients

Only in fitspecacum: fitted values, residuals and nonlinear model coefficients. For method = "random" these are matrices with a column for each random accumulation.

models

Only in fitspecaccum: list of fitted nls models (see Examples on accessing these models).

References

Chiarucci, A., Bacaro, G., Rocchini, D. & Fattorini, L. (2008). Discovering and rediscovering the sample-based rarefaction formula in the ecological literature. Commun. Ecol. 9: 121–123.

Coleman, B.D, Mares, M.A., Willis, M.R. & Hsieh, Y. (1982). Randomness, area and species richness. Ecology 63: 1121–1133.

Colwell, R.K., Chao, A., Gotelli, N.J., Lin, S.Y., Mao, C.X., Chazdon, R.L. & Longino, J.T. (2012). Models and estimators linking individual-based and sample-based rarefaction, extrapolation and comparison of assemblages. J. Plant Ecol. 5: 3–21.

Dengler, J. (2009). Which function describes the species-area relationship best? A review and empirical evaluation. Journal of Biogeography 36, 728–744.

Gotelli, N.J. & Colwell, R.K. (2001). Quantifying biodiversity: procedures and pitfalls in measurement and comparison of species richness. Ecol. Lett. 4, 379–391.

Author

Roeland Kindt r.kindt@cgiar.org and Jari Oksanen.

Note

The SAC with method = "exact" was developed by Roeland Kindt, and its standard deviation by Jari Oksanen (both are unpublished). The method = "coleman" underestimates the SAC because it does not handle properly sampling without replacement. Further, its standard deviation does not take into account species correlations, and is generally too low.

See also

rarefy and rrarefy are related individual based models. Other accumulation models are poolaccum for extrapolated richness, and renyiaccum and tsallisaccum for diversity indices. Underlying graphical functions are boxplot, matlines, segments and polygon.

Examples

data(BCI)
sp1 <- specaccum(BCI)
#> Warning: the standard deviation is zero
sp2 <- specaccum(BCI, "random")
sp2
#> Species Accumulation Curve
#> Accumulation method: random, with 100 permutations
#> Call: specaccum(comm = BCI, method = "random") 
#> 
#>                                                                             
#> Sites     1.0000   2.00000   3.00000   4.00000   5.00000   6.00000   7.00000
#> Richness 89.5100 121.67000 139.19000 151.63000 160.07000 166.78000 172.31000
#> sd        7.1612   7.86766   6.87801   6.21932   6.22516   5.37029   5.08254
#>                                                                              
#> Sites      8.00000   9.00000  10.00000  11.0000  12.00000  13.00000  14.00000
#> Richness 176.61000 180.37000 183.71000 186.6000 188.96000 191.04000 193.03000
#> sd         4.76497   4.80668   4.46602   4.6188   4.47647   4.39219   4.29812
#>                                                                              
#> Sites     15.00000  16.0000  17.00000  18.00000  19.00000  20.00000  21.00000
#> Richness 195.03000 196.6600 198.31000 199.83000 201.30000 202.69000 203.89000
#> sd         4.19344   3.9955   3.79977   3.78475   3.71048   3.71373   3.48415
#>                                                                               
#> Sites     22.00000  23.00000  24.00000  25.00000  26.00000  27.00000  28.00000
#> Richness 205.10000 206.42000 207.53000 208.50000 209.52000 210.52000 211.47000
#> sd         3.58307   3.53676   3.47125   3.35598   3.27365   3.15742   3.08615
#>                                                                              
#> Sites     29.0000  30.00000  31.00000  32.00000  33.00000  34.00000  35.00000
#> Richness 212.3400 213.16000 213.81000 214.57000 215.26000 215.94000 216.48000
#> sd         2.9481   2.77332   2.76228   2.54358   2.38945   2.37334   2.30274
#>                                                                              
#> Sites     36.00000  37.00000  38.0000  39.00000  40.00000  41.00000  42.00000
#> Richness 217.33000 217.96000 218.6000 219.29000 220.02000 220.74000 221.20000
#> sd         2.31837   2.29149   2.2202   2.15226   2.03495   1.88358   1.76383
#>                                                                               
#> Sites     43.00000  44.00000  45.00000  46.00000  47.00000  48.00000  49.00000
#> Richness 221.67000 222.14000 222.57000 223.26000 223.72000 224.01000 224.55000
#> sd         1.68208   1.63929   1.45821   1.26826   1.11988   0.96917   0.64157
#>             
#> Sites     50
#> Richness 225
#> sd         0
summary(sp2)
#>  1 sites          2 sites         3 sites         4 sites        
#>  Min.   : 77.00   Min.   :105.0   Min.   :124.0   Min.   :137.0  
#>  1st Qu.: 84.00   1st Qu.:117.0   1st Qu.:135.0   1st Qu.:147.8  
#>  Median : 89.00   Median :121.0   Median :139.0   Median :151.0  
#>  Mean   : 89.51   Mean   :121.7   Mean   :139.2   Mean   :151.6  
#>  3rd Qu.: 93.00   3rd Qu.:127.2   3rd Qu.:144.0   3rd Qu.:155.2  
#>  Max.   :109.00   Max.   :139.0   Max.   :155.0   Max.   :164.0  
#>  5 sites         6 sites         7 sites         8 sites        
#>  Min.   :143.0   Min.   :155.0   Min.   :162.0   Min.   :166.0  
#>  1st Qu.:156.8   1st Qu.:163.0   1st Qu.:168.8   1st Qu.:174.0  
#>  Median :161.0   Median :167.0   Median :173.0   Median :176.5  
#>  Mean   :160.1   Mean   :166.8   Mean   :172.3   Mean   :176.6  
#>  3rd Qu.:164.0   3rd Qu.:170.2   3rd Qu.:176.0   3rd Qu.:180.0  
#>  Max.   :172.0   Max.   :177.0   Max.   :182.0   Max.   :188.0  
#>  9 sites         10 sites        11 sites        12 sites        13 sites     
#>  Min.   :169.0   Min.   :173.0   Min.   :178.0   Min.   :180.0   Min.   :181  
#>  1st Qu.:178.0   1st Qu.:180.0   1st Qu.:183.0   1st Qu.:185.8   1st Qu.:188  
#>  Median :180.0   Median :184.0   Median :187.0   Median :189.0   Median :191  
#>  Mean   :180.4   Mean   :183.7   Mean   :186.6   Mean   :189.0   Mean   :191  
#>  3rd Qu.:184.0   3rd Qu.:187.0   3rd Qu.:190.0   3rd Qu.:192.0   3rd Qu.:194  
#>  Max.   :192.0   Max.   :195.0   Max.   :198.0   Max.   :201.0   Max.   :203  
#>  14 sites      15 sites      16 sites        17 sites        18 sites       
#>  Min.   :184   Min.   :186   Min.   :187.0   Min.   :189.0   Min.   :190.0  
#>  1st Qu.:190   1st Qu.:192   1st Qu.:194.0   1st Qu.:196.0   1st Qu.:197.0  
#>  Median :193   Median :195   Median :197.0   Median :198.0   Median :200.0  
#>  Mean   :193   Mean   :195   Mean   :196.7   Mean   :198.3   Mean   :199.8  
#>  3rd Qu.:196   3rd Qu.:198   3rd Qu.:199.0   3rd Qu.:201.0   3rd Qu.:202.0  
#>  Max.   :203   Max.   :208   Max.   :209.0   Max.   :209.0   Max.   :210.0  
#>  19 sites        20 sites        21 sites        22 sites       
#>  Min.   :193.0   Min.   :195.0   Min.   :197.0   Min.   :197.0  
#>  1st Qu.:199.0   1st Qu.:200.0   1st Qu.:202.0   1st Qu.:203.0  
#>  Median :201.0   Median :202.5   Median :204.0   Median :205.0  
#>  Mean   :201.3   Mean   :202.7   Mean   :203.9   Mean   :205.1  
#>  3rd Qu.:203.0   3rd Qu.:205.0   3rd Qu.:206.0   3rd Qu.:207.0  
#>  Max.   :211.0   Max.   :212.0   Max.   :213.0   Max.   :215.0  
#>  23 sites        24 sites        25 sites        26 sites       
#>  Min.   :198.0   Min.   :199.0   Min.   :200.0   Min.   :202.0  
#>  1st Qu.:204.0   1st Qu.:205.0   1st Qu.:207.0   1st Qu.:208.0  
#>  Median :207.0   Median :208.0   Median :208.0   Median :209.0  
#>  Mean   :206.4   Mean   :207.5   Mean   :208.5   Mean   :209.5  
#>  3rd Qu.:208.0   3rd Qu.:209.0   3rd Qu.:210.2   3rd Qu.:212.0  
#>  Max.   :217.0   Max.   :218.0   Max.   :219.0   Max.   :219.0  
#>  27 sites        28 sites        29 sites        30 sites       
#>  Min.   :203.0   Min.   :204.0   Min.   :205.0   Min.   :206.0  
#>  1st Qu.:208.0   1st Qu.:209.8   1st Qu.:210.0   1st Qu.:211.0  
#>  Median :210.5   Median :211.0   Median :212.0   Median :213.0  
#>  Mean   :210.5   Mean   :211.5   Mean   :212.3   Mean   :213.2  
#>  3rd Qu.:213.0   3rd Qu.:214.0   3rd Qu.:215.0   3rd Qu.:215.0  
#>  Max.   :219.0   Max.   :220.0   Max.   :220.0   Max.   :220.0  
#>  31 sites        32 sites        33 sites        34 sites       
#>  Min.   :207.0   Min.   :208.0   Min.   :210.0   Min.   :210.0  
#>  1st Qu.:212.0   1st Qu.:213.0   1st Qu.:214.0   1st Qu.:214.0  
#>  Median :213.5   Median :214.0   Median :215.0   Median :216.0  
#>  Mean   :213.8   Mean   :214.6   Mean   :215.3   Mean   :215.9  
#>  3rd Qu.:216.0   3rd Qu.:216.0   3rd Qu.:217.0   3rd Qu.:218.0  
#>  Max.   :221.0   Max.   :221.0   Max.   :221.0   Max.   :221.0  
#>  35 sites        36 sites        37 sites        38 sites       
#>  Min.   :211.0   Min.   :212.0   Min.   :213.0   Min.   :214.0  
#>  1st Qu.:215.0   1st Qu.:216.0   1st Qu.:216.8   1st Qu.:217.0  
#>  Median :216.5   Median :217.0   Median :218.0   Median :219.0  
#>  Mean   :216.5   Mean   :217.3   Mean   :218.0   Mean   :218.6  
#>  3rd Qu.:218.0   3rd Qu.:219.0   3rd Qu.:219.2   3rd Qu.:220.0  
#>  Max.   :222.0   Max.   :223.0   Max.   :223.0   Max.   :223.0  
#>  39 sites        40 sites      41 sites        42 sites        43 sites       
#>  Min.   :214.0   Min.   :215   Min.   :216.0   Min.   :217.0   Min.   :217.0  
#>  1st Qu.:217.0   1st Qu.:219   1st Qu.:219.0   1st Qu.:220.0   1st Qu.:221.0  
#>  Median :220.0   Median :220   Median :221.0   Median :221.0   Median :222.0  
#>  Mean   :219.3   Mean   :220   Mean   :220.7   Mean   :221.2   Mean   :221.7  
#>  3rd Qu.:221.0   3rd Qu.:221   3rd Qu.:222.0   3rd Qu.:222.0   3rd Qu.:223.0  
#>  Max.   :224.0   Max.   :224   Max.   :224.0   Max.   :225.0   Max.   :225.0  
#>  44 sites        45 sites        46 sites        47 sites        48 sites     
#>  Min.   :218.0   Min.   :218.0   Min.   :219.0   Min.   :220.0   Min.   :221  
#>  1st Qu.:221.0   1st Qu.:222.0   1st Qu.:222.8   1st Qu.:223.0   1st Qu.:223  
#>  Median :222.0   Median :223.0   Median :223.5   Median :224.0   Median :224  
#>  Mean   :222.1   Mean   :222.6   Mean   :223.3   Mean   :223.7   Mean   :224  
#>  3rd Qu.:223.0   3rd Qu.:224.0   3rd Qu.:224.0   3rd Qu.:225.0   3rd Qu.:225  
#>  Max.   :225.0   Max.   :225.0   Max.   :225.0   Max.   :225.0   Max.   :225  
#>  49 sites        50 sites     
#>  Min.   :222.0   Min.   :225  
#>  1st Qu.:224.0   1st Qu.:225  
#>  Median :225.0   Median :225  
#>  Mean   :224.6   Mean   :225  
#>  3rd Qu.:225.0   3rd Qu.:225  
#>  Max.   :225.0   Max.   :225  
plot(sp1, ci.type="poly", col="blue", lwd=2, ci.lty=0, ci.col="lightblue")
boxplot(sp2, col="yellow", add=TRUE, pch="+")

## Fit Lomolino model to the exact accumulation
mod1 <- fitspecaccum(sp1, "lomolino")
coef(mod1)
#>       Asym       xmid      slope 
#> 258.440682   2.442061   1.858694 
fitted(mod1)
#>  [1]  94.34749 121.23271 137.45031 148.83053 157.45735 164.31866 169.95946
#>  [8] 174.71115 178.78954 182.34254 185.47566 188.26658 190.77402 193.04337
#> [15] 195.11033 197.00350 198.74606 200.35705 201.85227 203.24499 204.54643
#> [22] 205.76612 206.91229 207.99203 209.01150 209.97609 210.89054 211.75903
#> [29] 212.58527 213.37256 214.12386 214.84180 215.52877 216.18692 216.81820
#> [36] 217.42437 218.00703 218.56767 219.10762 219.62811 220.13027 220.61514
#> [43] 221.08369 221.53679 221.97528 222.39991 222.81138 223.21037 223.59747
#> [50] 223.97327
plot(sp1)
## Add Lomolino model using argument 'add'
plot(mod1, add = TRUE, col=2, lwd=2)

## Fit Arrhenius models to all random accumulations
mods <- fitspecaccum(sp2, "arrh")
plot(mods, col="hotpink")
boxplot(sp2, col = "yellow", border = "blue", lty=1, cex=0.3, add= TRUE)

## Use nls() methods to the list of models
sapply(mods$models, AIC)
#>   [1] 336.0792 340.6693 336.9187 327.7249 352.8915 329.2000 321.8194 309.8682
#>   [9] 332.7265 335.3696 342.3049 349.4023 295.0378 335.3567 356.7021 342.6430
#>  [17] 328.4580 327.5102 310.1210 311.2499 311.9706 354.9492 357.2030 338.0017
#>  [25] 361.3667 366.0461 312.4395 316.1461 336.2027 330.7645 347.5582 366.2146
#>  [33] 347.8397 353.9612 318.8787 355.9027 349.2560 340.2121 327.7220 345.3082
#>  [41] 340.9499 335.6730 340.3947 313.4887 295.2562 338.4193 341.9489 383.6567
#>  [49] 339.2980 311.6285 322.4878 365.7398 329.8658 316.6981 326.2933 366.8075
#>  [57] 347.9566 331.2418 358.4818 359.6695 320.3111 336.6999 351.9354 325.4214
#>  [65] 348.6616 340.7211 333.5741 347.1177 363.0260 349.5925 305.2396 373.6744
#>  [73] 361.0716 329.9779 325.0650 341.1335 289.2760 337.9666 347.8689 339.9338
#>  [81] 343.2062 312.9914 326.2825 345.1074 333.5841 310.4789 356.3000 342.6993
#>  [89] 349.4500 337.3851 356.5151 316.7041 330.2879 346.3311 354.5695 321.2458
#>  [97] 332.9982 314.1864 301.5734 349.2857