vegan-deprecated: Deprecated Functions in vegan package

vegan-deprecatedR Documentation

Deprecated Functions in vegan package

Description

These functions are provided for compatibility with older versions of vegan only, and may be defunct as soon as the next release.

Usage


## use toCoda instead
as.mcmc.oecosimu(x)
as.mcmc.permat(x)

Arguments

x

object to be transformed.

Details

as.mcmc functions were replaced with toCoda.

See Also

Deprecated


vegan documentation built on March 4, 2026, 9:07 a.m.