| vegan-deprecated | R Documentation |
These functions are provided for compatibility with older versions of vegan only, and may be defunct as soon as the next release.
## use toCoda instead
as.mcmc.oecosimu(x)
as.mcmc.permat(x)
x |
object to be transformed. |
as.mcmc functions were replaced with toCoda.
Deprecated
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.