Skip to contents

These functions are provided for compatibility with older versions of vegan only, and may be defunct as soon as the next release.

Usage

## Following lattice functions are deprecated. Use ggplot2 functions
## in the CRAN package ggvegan instead

ordixyplot(x, data = NULL, formula, display = "sites", choices = 1:3,
    panel = "panel.ordi", aspect = "iso", envfit,
    type = c("p", "biplot"), ...)
# S3 method for class 'poolaccum'
plot(x, alpha = 0.05, type = c("l","g"), ...)
# S3 method for class 'renyi'
plot(x, ...)
# S3 method for class 'renyiaccum'
plot(x, what = c("Collector", "mean", "Qnt 0.025",
    "Qnt 0.975"),
     type = "l", ...)
permulattice(x, plot = c("densityplot", "qqmath"), observed = TRUE,
    axislab = "Permutations", ...)
# S3 method for class 'permustats'
densityplot(x, data, observed = TRUE,
    xlab = "Permutations", ...)
# S3 method for class 'permustats'
qqmath(x, data, observed = TRUE, sd.scale = FALSE,
    ylab = "Permutations", ...)

## use toCoda instead
as.mcmc.oecosimu(x)
as.mcmc.permat(x)

Arguments

x

input object

data

Optional data to amend ordination results. The ordination results are found from x, but you may give here data for other variables needed in plots. Typically these are environmental data.

formula

Formula to define the plots. A default formula will be used if this is omitted. The ordination axes must be called by the same names as in the ordination results (and these names vary among methods).

display

The kind of scores: an argument passed to scores.

choices

The axes selected: an argument passed to scores.

panel

The name of the panel function.

aspect

The aspect of the plot (passed to the lattice function).

envfit

Result of envfit function displayed in ordixyplot. Please note that this needs same choices as ordixyplot.

type

The type of plot. This knows the same alternatives as panel.xyplot. In addition ordixyplot has alternatives "biplot", "arrows" and "polygon". The first displays fitted vectors and factor centroids of envfit, or in constrained ordination, the biplot arrows and factor centroids if envfit is not given. The second (type = "arrows") is a trellis variant of ordiarrows and draws arrows by groups. The line parameters are controlled by trellis.par.set for superpose.line, and the user can set length, angle and ends parameters of panel.arrows. The last one (type = "polygon") draws a polygon enclosing all points in a panel over a polygon enclosing all points in the data. The overall polygon is controlled by Trellis parameters trellis.par.set plot.polygon and superpose.polygon.

what

Items to be plotted.

plot

Use lattice function densityplot or qqmath.

xlab, ylab, axislab

Label for the axis displaying permutation values.

observed

Add observed statistic among permutations.

sd.scale

Scale permutations to unit standard deviation and observed statistic to standardized effect size.

alpha

Level of quantiles shown. This proportion will be left outside symmetric limits.

...

Arguments passed to scores methods or lattice functions.

Details

as.mcmc functions were replaced with toCoda.

Better alternatives to lattice functions are provided by ggplot2 functions in the ggvegan package. ggvegan::autoplot functions are most similar to these deprecated functions.

See also