The function vegemite prints a traditional community table.
The display is transposed so that species are in rows and sites in
columns. The table is printed in compact form: only one character
can be used for abundance, and there are no spaces between
columns. Species with no occurrences are dropped from the table.
Function tabasco produces a similar table as vegemite
using heatmap, where abundances are coded by
colours. The function scales the abundances to equal intervals for
colour palette, but either rows or columns can be scaled to equal
maxima, or a coverscale class systems can be used. The function
can also display dendrograms for sites (columns) or species if these
are given as an argument (use for sites, sp.ind for
species).
The parameter use will be used to re-order output. The
use can be a vector or an object from hclust or
agnes, a dendrogram or any
ordination result recognized by scores (all ordination
methods in vegan and some of those not in vegan). The
hclust, agnes and
dendrogram must be for sites. The dendrogram is
displayed above the sites in tabasco, but is not shown in
vegemite. In tabasco the species dendrogram can be
given in sp.ind.
If use is a numeric vector, it is used for ordering sites, and
if it is a factor, it is used to order sites by classes. If use
is an object from ordination, both sites and species are arranged by
the first axis (provided that results are available also for species).
When use is an object from hclust,
agnes or dendrogram, the sites
are ordered similarly as in the cluster dendrogram. Function
tabasco re-orders the dendrogram to give a diagonal pattern if
Rowv = TRUE. Alternatively, if Rowv is a vector its
values are used to re-order dendrogram. With diagonalize = TRUE
the dendrogram will be re-ordered in vegemite to give a
diagonal pattern. If use is a factor, its levels and sites
within levels will be reordered to give a diagonal pattern if
diagonalize = TRUE in vegemite or Rowv = TRUE in
tabasco. In all cases where species scores are missing, species
are ordered by their weighted averages (wascores) on
site order or site value.
Species and sites can be ordered explicitly giving their indices or
names in parameters sp.ind and site.ind. Argument
use takes precedence, and site.ind cannot be used
together with use. However, sp.index takes precedence
over species order of use. A subset of sites can be displayed
using argument select, but this cannot be used to order sites,
but you still must give use or site.ind. However,
tabasco makes two exceptions: site.ind and select
cannot be used when use is a dendrogram (clustering result). In
addition, the sp.ind can be an hclust tree,
agnes clustering or a dendrogram,
and in that case the dendrogram is plotted on the left side of the
heatmap, and Colv can be used to reorder the
dendrogram. Phylogenetic trees cannot be directly used, but package
ape has tools to transform these to hclust trees.
If scale is given, vegemite calls coverscale to
transform percent cover scale or some other scales into traditional
class scales used in vegetation science (coverscale can be
called directly, too). Function tabasco can also use these
traditional class scales, but it treats the transformed values as
corresponding integers. Braun-Blanquet and Domin scales are
actually not strict cover scales, and the limits used for codes
r and + are arbitrary. Scale Hill may be
inappropriately named, since Mark O. Hill probably never intended
this as a cover scale. However, it is used as default “cut levels”
in his TWINSPAN, and surprisingly many users stick to this
default, and this is a de facto standard in publications.
All traditional scales assume that values are cover percentages with
maximum 100. However, non-traditional alternative log can be
used with any scale range. Its class limits are integer powers of
1/2 of the maximum (argument maxabund), with + used
for non-zero entries less than 1/512 of the maximum (log
stands alternatively for logarithmic or logical). Scale fix
is intended for “fixing” 10-point scales: it truncates scale values
to integers, and replaces 10 with X and positive values below
1 with +.